@@ -22,6 +22,7 @@
 ;;{{{ Load some required packages
 (require 'mailcrypt)
 (require 'mail-utils)
+(require 'rfc822)
 
 (eval-when-compile
   ;; RMAIL
@@ -56,7 +57,7 @@
   ;; assuming they were possibly extracted from the headers of a reply,
   ;; returns a list of the address components.
   (mapcar 'mc-strip-address
-	  (mc-split "\\([ \t\n]*,[ \t\n]*\\)+" str)))
+	  (rfc822-addresses str)))
 
 (defun mc-find-headers-end ()
   (save-excursion
@@ -574,20 +575,20 @@ Exact behavior depends on current major mode."
 
 (defun mc-gnus-verify-signature ()
   (interactive)
-  (gnus-summary-select-article)
+  (gnus-summary-select-article t)
   (save-excursion
     (set-buffer gnus-original-article-buffer)
     (save-restriction (widen) (mc-verify-signature))))
 
 (defun mc-gnus-snarf-keys ()
   (interactive)
-  (gnus-summary-select-article)
+  (gnus-summary-select-article t)
   (gnus-eval-in-buffer-window gnus-original-article-buffer
     (save-restriction (widen) (mc-snarf-keys))))
 
 (defun mc-gnus-decrypt-message ()
   (interactive)
-  (gnus-summary-select-article)
+  (gnus-summary-select-article t)
   ;; Gnus 5 has the string "Gnus" instead of "GNUS" in gnus-version.
   (if (not (let ((case-fold-search nil))
 	     (string-match "Gnus" gnus-version)))
@@ -650,7 +651,8 @@ Exact behavior depends on current major mode."
 	(set-buffer mh-show-buffer)
       (let ((tmp (generate-new-buffer "*Mailcrypt Viewing*")))
         (copy-to-buffer tmp (point-min) (point-max))
-        (switch-to-buffer tmp t)
+        ;(switch-to-buffer tmp t)
+	(set-buffer tmp)
         (goto-char (point-min))
         (set-buffer-modified-p nil)
         (if (setq decrypt-okay (car (mc-decrypt-message)))
